/*******************************************************************************
 *                                      *                                      *
 *    HOLDUP BV                         *    STOGGER BV                        *
 *    Nachtegaalstraat 8                *    Haagveld 1A                       *
 *    5988 NG  Helden                   *    5981 PK  Panningen                *
 *    The Netherlands                   *    The Netherlands                   *
 *                                      *                                      *
 *******************************************************************************
 *                                      *                                      *
 *    Aubert Dupont                     *                                      *
 *    aubert@holdup.nl                  *                                      *
 *                                      *                                      *
 *******************************************************************************
 *                                                                             *
 *    Project    -   STOGGER - E-41-2000 - Ventilator PAL                      *
 *    Author     -   Aubert Dupont                                             *
 *    Build Tool -   MPLAB X IDE v4.15 & MPLAB XC8 v1.45                       *
 *    Revision   -   1.01                                                      *
 *    Date       -   2020-04-01                                                *
 *    Function   -   System definition file                                    *
 *    File       -   system.h                                                  *
 *                                                                             *
 *******************************************************************************
 *                                                                             *
 *    (C)  2020  HOLDUP BV         ALL RIGHTS RESERVED                         *
 *    (C)  2020  STOGGER BV        ALL RIGHTS RESERVED                         *
 *                                                                             *
 ******************************************************************************/

/*******************************************************************************
 *
 *   Documentation / Functional description
 *
 *******************************************************************************
 *
 ******************************************************************************/

/*******************************************************************************
 ** Start Header Definition
 ******************************************************************************/

/*******************************************************************************
 ** Macro defintions
 ******************************************************************************/

#define GlobalInterruptEnable()        (INTCONbits.GIE = 1)
#define GlobalInterruptDisable()       (INTCONbits.GIE = 0)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define PeripheralInterruptEnable()    (INTCONbits.PEIE = 1)
#define PeripheralInterruptDisable()   (INTCONbits.PEIE = 0)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define SerialRxOn()                   (RCSTAbits.CREN = 1)
#define SerialRxOff()                  (RCSTAbits.CREN = 0)
#define SerialRxFrameValid()           (RCSTAbits.FERR == 0)
#define SerialRxFrameError()           (RCSTAbits.FERR == 1)
#define SerialRxBufferValid()          (RCSTAbits.OERR == 0)
#define SerialRxBufferError()          (RCSTAbits.OERR == 1)
#define SerialRxReady()                (PIR1bits.RCIF == 1)
#define SerialRxChar()                 (RCREG)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define SerialTxOn()                   (TXSTAbits.TXEN = 1)
#define SerialTxOff()                  (TXSTAbits.TXEN = 0)
#define SerialTxReady()                (TXSTAbits.TRMT == 1)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define MotionTimerOn()                (T1CONbits.TMR1ON = 1)
#define MotionTimerOff()               (T1CONbits.TMR1ON = 0)
#define MotionTimerRunning()           (T1CONbits.TMR1ON == 1)
#define MotionTimerStopped()           (T1CONbits.TMR1ON == 0)
#define MotionTimerWrite(Data)         (TMR1 = Data)
#define MotionTimerRead()              (TMR1)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define ProcessTimerOn()               (T2CONbits.TMR2ON = 1)
#define ProcessTimerOff()              (T2CONbits.TMR2ON = 0)
#define ProcessTimerFlagged()          (PIR1bits.TMR2IF == 1)
#define ProcessTimerClearFlag()        (PIR1bits.TMR2IF = 0)

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define i_HOME                         (CMOUTbits.MC1OUT)
#define i_FAULT                        (CMOUTbits.MC2OUT)

/*******************************************************************************
 ** System Function Prototypes
 ******************************************************************************/

void ConfigureOscillator (void);
void ConfigureWatchdog (void);
void ConfigurePorts (void);
void ConfigureInterrupts (void);
void ConfigurePeripherals (void);

/******************************************************************************/

void SerialTxChar (uint8_t _Char);

/******************************************************************************/

uint8_t EepromRead (uint8_t _Address);
void EepromWrite (uint8_t _Address, uint8_t _Byte);

/*******************************************************************************
 ** END-O-HEADER
 ******************************************************************************/
