/*******************************************************************************
 *                                      *                                      *
 *    HOLDUP BV                         *    STOGGER BV                        *
 *    Nachtegaalstraat 8                *    Haagveld 1A                       *
 *    5988 NG  Helden                   *    5981 PK  Panningen                *
 *    The Netherlands                   *    The Netherlands                   *
 *                                      *                                      *
 *******************************************************************************
 *                                      *                                      *
 *    Aubert Dupont                     *                                      *
 *    aubert@holdup.nl                  *                                      *
 *                                      *                                      *
 *******************************************************************************
 *                                                                             *
 *    Project    -   STOGGER - E-41-2000 - Ventilator PAL                      *
 *    Author     -   Aubert Dupont                                             *
 *    Build Tool -   MPLAB X IDE v4.15 & MPLAB XC8 v1.45                       *
 *    Revision   -   1.01                                                      *
 *    Date       -   2020-04-01                                                *
 *    Function   -   Config definition file                                    *
 *    File       -   config.h                                                  *
 *                                                                             *
 *******************************************************************************
 *                                                                             *
 *    (C)  2020  HOLDUP BV         ALL RIGHTS RESERVED                         *
 *    (C)  2020  STOGGER BV        ALL RIGHTS RESERVED                         *
 *                                                                             *
 ******************************************************************************/

/*******************************************************************************
 *
 *   Documentation / Functional description
 *
 *******************************************************************************
 *
 *   ROM memory layout:
 *   ==================
 *
 *   ||=====================================||
 *   || OFFSET | Description                ||
 *   ||=====================================||
 *
 *   ||=====================================||
 *   || 0x0000 | Reset Vector               ||
 *   || 0x0004 | Interrupt Vector           ||
 *   ||-------------------------------------||
 *   || 0x0006 | Boot Loader Program        ||
 *   || - -- - |                            ||
 *   || - -- - |                            ||
 *   || 0x04DF | Boot Loader Program End    ||
 *   ||-------------------------------------||
 *   || 0x04E0 | Boot Loader RECORD         ||
 *   || - -- - |                            ||
 *   || 0x04FF | Boot Loader RECORD End     ||
 *   ||=====================================||
 *
 *   ||=====================================||
 *   || 0x0500 | Program (Reset Vector)     ||
 *   || 0x0504 | Program (Interrupt Vector) ||
 *   ||-------------------------------------||
 *   || 0x0506 | Program                    ||
 *   || - -- - |                            ||
 *   || - -- - |                            ||
 *   || - -- - |                            ||
 *   || - -- - |                            ||
 *   || 0x3FDF | Program End                ||
 *   ||-------------------------------------||
 *   || 0x3FE0 | Program RECORD             ||
 *   || - -- - |                            ||
 *   || 0x3FFF | Program RECORD End         ||
 *   ||=====================================||
 *
 *
 *   Boot Loader Record layout:
 *   ==========================
 *
 *   ||==============================================||
 *   || MEMORY | LENGTH | Description                ||
 *   ||==============================================||
 *   || 0x04E0 |      8 | Boot Loader ID text        ||
 *   || 0x04E8 |     12 | Boot Loader ID date        ||
 *   || 0x04F4 |      1 | Boot Loader ID code        ||
 *   || 0x04F5 |      1 | Boot Loader Major Version  ||
 *   || 0x04F6 |      1 | Boot Loader Minor Version  ||
 *   || 0x04F7 |      9 | reserved space for future  ||
 *   ||==============================================||
 *
 *
 *   Program Record layout:
 *   ======================
 *
 *   ||==============================================||
 *   || MEMORY | LENGTH | Description                ||
 *   ||==============================================||
 *   || 0x3FE0 |      8 | Program ID text            ||
 *   || 0x3FE8 |     12 | Program ID date            ||
 *   || 0x3FF4 |      1 | Program ID code            ||
 *   || 0x3FF5 |      1 | Program Major Version      ||
 *   || 0x3FF6 |      1 | Program Minor Version      ||
 *   || 0x3FF7 |      1 | Program Image Checksum     ||
 *   || 0x3FF8 |      8 | reserved space for future  ||
 *   ||==============================================||
 *
 *
 *******************************************************************************
 *
 *   BOOT LOADER compiler settings:
 *   ==============================
 *   ROM ranges: 0000-04DF
 *
 *   USER PROGRAM compiler settings:
 *   ===============================
 *   Codeoffset: 0500
 *   Checksum:   0500-3FDF@3FF7,width=-2,algorithm=2
 *
 *******************************************************************************
 *
 *   The hardware port I/O defines legend is as follows:
 *   ===================================================
 *   m_... = MACRO definition
 *   p_... = PORT register definition
 *   t_... = TRIS data direction port definition
 *   a_... = ANALOG INPUT port definition
 *   c_... = ANALOG CHANNEL port definition
 *   d_... = ANALOG OUTPUT port definition
 *   i_... = DIGITAL INPUT port definition
 *   o_... = DIGITAL OUTPUT port definition
 *
 *******************************************************************************
 *
 *   PIC16F1788 pin defintion, see board schematics and pin definitions files
 *
 ******************************************************************************/

/*******************************************************************************
 ** ROM Memory Layout definitions
 ******************************************************************************/

#define BOOT_BASE            0x0000              // Boot Loader base address
#define BOOT_END             0x04DF              // Boot Loader end address

#define BOOT_VRES            BOOT_BASE           // Boot Loader entry point
#define BOOT_VINT            BOOT_BASE + 0x0004  // Boot Loader interrupt vector

#define BOOT_RIDT            0x04E0              // Boot Loader Record ID text
#define BOOT_RIDD            0x04E8              // Boot Loader Record ID date
#define BOOT_RIDC            0x04F4              // Boot Loader Record ID code
#define BOOT_RMAV            0x04F5              // Boot Loader Record Major Version
#define BOOT_RMIV            0x04F6              // Boot Loader Record Minor Version
#define BOOT_REND            0x04FF              // Boot Loader Record END

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define PROG_BASE            0x0500              // Program base address
#define PROG_END             0x3FDF              // Program end address

#define PROG_VRES            PROG_BASE           // Program entry point
#define PROG_VINT            PROG_BASE + 0x0004  // Program interrupt vector

#define PROG_RIDT            0x3FE0              // Program Record ID text
#define PROG_RIDD            0x3FE8              // Program Record ID date
#define PROG_RIDC            0x3FF4              // Program Record ID code
#define PROG_RMAV            0x3FF5              // Program Record Major Version
#define PROG_RMIV            0x3FF6              // Program Record Minor Version
#define PROG_RCRC            0x3FF7              // Program Record Checksum
#define PROG_REND            0x3FFF              // Program Record END

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define ROM_MASK             0x3FFF              // Flash ROM data mask (14-bits)
#define ROM_BLOCK            32                  // Flash ROM block size (words)

/*******************************************************************************
 ** Boot Loader Definitions
 ******************************************************************************/

#define RIDC_VOLUCI          0x01                // ID code for BALMOD v3.1 PCB
#define RIDC_JUPITER         0x02                // ID code for Accerion Jupiter
#define RIDC_WOLKYTOLKY      0x03                // ID code for WolkyTolky
#define RIDC_NELSON          0x04                // ID code for Nelson Candela
#define RIDC_VENPAL_1788     0x05                // ID code for Ventilator PAL using PIC16F1788

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define BL_REGISTER          T1GCON              // BL register survives reset
#define BL_FLAG              T1GCONbits.T1GSS    // BL flag survives reset
#define BL_FLAG_FRBL         0b00                // BL flag First Run Boot Loader
#define BL_FLAG_FRUP         0b01                // BL flag First Run User Program
#define BL_FLAG_WDTR         0b10                // BL flag Watch Dog Timer Reset
#define BL_FLAG_BLRQ         0b11                // BL flag Boot Loader ReQuested

/*******************************************************************************
 ** Hardware Definitions
 ******************************************************************************/

#define FREQ_OSC             32000000UL          // The internal frequency
#define FREQ_CPU             (FREQ_OSC/4)        // The CPU core frequency
#define _XTAL_FREQ           FREQ_OSC            // For delay functions

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define I_PORT               0b11111111          // TRIS define port INPUT
#define O_PORT               0b00000000          // TRIS define port OUTPUT
#define I_PIN                1                   // TRIS define pin INPUT
#define O_PIN                0                   // TRIS define pin OUTPUT

/*******************************************************************************
 ** I/O port pin definitions
 ******************************************************************************/

/////// ICSP -------------------------------------------------------------------
#define t_ICSP_VPP           TRISEbits.TRISE3    // DIGITAL - MCLR / VPP
#define t_ICSP_CLK           TRISBbits.TRISB6    // DIGITAL - ICSP CLK
#define t_ICSP_DAT           TRISBbits.TRISB7    // DIGITAL - ICSP DAT
#define i_ICSP_VPP           PORTEbits.RE3       // INPUT   - MCLR / VPP
#define i_ICSP_CLK           PORTBbits.RB6       // INPUT   - ICSP CLK
#define i_ICSP_DAT           PORTBbits.RB7       // INPUT   - ICSP DAT

/////// ANALOGUE PORTS ---------------------------------------------------------
#define t_HOME               TRISAbits.TRISA0    // DIGITAL - Home Sensor
#define t_FAULT              TRISAbits.TRISA1    // DIGITAL - Driver Fault
#define t_VREF               TRISAbits.TRISA2    // DIGITAL - Reference Voltage
#define t_STATE              TRISAbits.TRISA5    // DIGITAL - State Voltage
#define a_HOME               ANSELAbits.ANSA0    // ANALOG  - Home Sensor
#define a_FAULT              ANSELAbits.ANSA1    // ANALOG  - Driver Fault
#define a_VREF               ANSELAbits.ANSA2    // ANALOG  - Driver Voltage
#define a_STATE              ANSELAbits.ANSA5    // ANALOG  - State Voltage
#define d_VREF               DAC1CON1            // DAC-OUT - Driver Voltage
#define d_STATE              DAC2CON1            // DAC-OUT - State Voltage

/////// MOTOR DRIVER -----------------------------------------------------------
#define t_STEP_CNT           TRISCbits.TRISC0    // DIGITAL - Step Counter Input
#define t_STEP               TRISCbits.TRISC1    // DIGITAL - Step Pulse Output
#define t_DIR                TRISCbits.TRISC2    // DIGITAL - Direction Output
#define t_MOTEN              TRISCbits.TRISC3    // DIGITAL - Motor Enable
#define i_STEP_CNT           PORTCbits.RC0       // INPUT   - Step Counter Input
#define o_STEP               LATCbits.LATC1      // OUTPUT  - Step Pulse Output
#define o_DIR                LATCbits.LATC2      // OUTPUT  - Direction Output
#define o_MOTEN              LATCbits.LATC3      // OUTPUT  - Motor Enable

/////// COMMUNICATION ----------------------------------------------------------
#define t_ERROR              TRISCbits.TRISC5    // DIGITAL - System Error
#define t_UART_TX            TRISCbits.TRISC6    // DIGITAL - Jetson UART RX
#define t_UART_RX            TRISCbits.TRISC7    // DIGITAL - Jetson UART TX
#define o_ERROR              LATCbits.LATC5      // OUTPUT  - System Error
#define o_UART_TX            LATCbits.LATC6      // OUTPUT  - Jetson UART RX
#define i_UART_RX            PORTCbits.RC7       // INPUT   - Jetson UART TX

/*******************************************************************************
 ** DRV8825 definitions
 ******************************************************************************/

#define DIR_DW               1                   // Moving down
#define DIR_UP               0                   // Moving up

/* -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  */

#define VREF_OFF             0x00                // Driver Voltage for OFF

/*******************************************************************************
 ** Typedefs
 ******************************************************************************/

typedef enum RETURN
{
  RETURN_OKAY                       = 0,
  RETURN_BOOTLOADER_REQUEST         = 1,
  RETURN_USERPROGRAM_ID_MISMATCH    = 2,
  RETURN_USERPROGRAM_CHECKSUM_ERROR = 3,
  RETURN_HEXRECORD_SIZE_ERROR       = 4,
  RETURN_HEXRECORD_CHECKSUM_ERROR   = 5,
  RETURN_HEXRECORD_INTEGRITY_ERROR  = 6,
  RETURN_HEXRECORD_UNKOWN_TYPE      = 7,
  RETURN_FLASH_WRITE_PROTECTED      = 8,
  RETURN_FLASH_WRITE_NO_DATA        = 9,
  RETURN_FLASH_WRITE_OVERRUN        = 10,
  RETURN_EXECUTING                  = 14,
  RETURN_REBOOTING                  = 15,
} ;

/*******************************************************************************
 ** END-O-HEADER
 ******************************************************************************/
