#!/bin/bash
#
# Generate Firmware Header file for Stogger Boot Loader, usage:
#
#  $1 = source file
#  $2 = destination file
#
# Written by Aubert Dupont
#
# Version 1.0 - 2020-04-03 - initial release
# Version 1.1 - 2020-04-14 - update filelayout to CosmicNode requirements
#

# Check the parameter
[ ! -n "$1" ] && exit 1

# Setup variables
DATE=$(date +"%Y-%m-%d %H:%M")
USER=$(grep ":107FE000" "$1")

# Create destination file header
echo "// ==========================================" > "$2"
echo "// Firmware $2" >> "$2"
echo "// Created on $DATE" >> "$2"
echo "// STOGGER (C) 2016-2020" >> "$2"
echo "// Do not edit this file!" >> "$2"
echo "// ==========================================" >> "$2"
echo "" >> "$2"
echo "#ifndef H_PIC_FIRMWARE_" >> "$2"
echo "#define H_PIC_FIRMWARE_" >> "$2"
echo "" >> "$2"
echo "#define PIC_USER_PROGRAM_TYPE_ID 0x${USER:25:2}" >> "$2"
echo "#define PIC_USER_PROGRAM_VER_MJR 0x${USER:29:2}" >> "$2"
echo "#define PIC_USER_PROGRAM_VER_MIN 0x${USER:33:2}" >> "$2"
echo "#define PIC_USER_PROGRAM_VERSION \"<${USER:29:2}${USER:33:2}><00>\"" >> "$2"
echo "" >> "$2"
echo "const char HexFlashRecords[][45] = {" >> "$2"

# Open source HEX file and parse it
grep -v "FF3FFF3FFF3FFF3FFF3FFF3FFF3FFF3F" "$1" | grep -v ":02"  | grep -v ":04"  | grep -v ":000000" | while read -r LINE
do
  echo "  \"$LINE;\"," >> "$2"
done

# Add final firmware check
echo "};" >> "$2"
echo "" >> "$2"
echo "#ifdef __cplusplus" >> "$2"
echo "}" >> "$2"
echo "#endif" >> "$2"
echo "" >> "$2"
echo "#endif" >> "$2"
echo "" >> "$2"

cp "$2" "pic_firmware.h"

# Exit w/o error code
exit 0

